@@ -3,16 +3,16 @@ context("summary.simsum")
 test_that("summarising a simsum object works fine and prints ok", {
   data("MIsim")
   x <- simsum(data = MIsim, estvarname = "b", true = 0.5, se = "se", methodvar = "method", mcse = TRUE)
-  print(summary(x))
-  print(summary(x, ci_level = 0.99))
+  expect_output(print(summary(x)))
+  expect_output(print(summary(x, ci_level = 0.99)))
   x <- simsum(data = MIsim, estvarname = "b", true = 0.5, se = "se")
-  print(summary(x))
+  expect_output(print(summary(x)))
   data("relhaz")
   x <- simsum(data = relhaz, estvarname = "theta", true = -0.5, se = "se", methodvar = "model", by = c("n", "baseline"))
-  print(summary(x))
-  print(summary(x), sstat = c("bias", "bccover"))
+  expect_output(print(summary(x)))
+  expect_output(print(summary(x), sstat = c("bias", "bccover")))
   x <- simsum(data = relhaz, estvarname = "theta", true = -0.5, se = "se", by = c("n", "baseline"))
-  print(summary(x), sstat = c("bias", "bccover"))
+  expect_output(print(summary(x), sstat = c("bias", "bccover")))
 })
 
 test_that("summary.simsum returns an object of class summary.simsum", {
